======
HAT: HESXRD-Analysis-Toolkit (xray-hat)
======

HAT is a Software package for the analysis of high-energy surface x-ray diffraction data.
This softwares allows one to extract meaningful data from stacks of images such as those
produced in high-energy-surface x-ray diffraction experiements.

It is designed to be user-friendly and fairly quick so that it can be easily used during an experiment

Thanks for checking it out.

All documentation is in the "``docs``" directory and online at
https://xray-hat.readthedocs.io/en/latest/. 

